@@ -14,6 +14,7 @@
 #include "jdlib/misctime.h"
 
 #include "controlid.h"
+#include "command.h"
 
 #include <sys/time.h>
 
@@ -35,7 +36,8 @@ ArticleViewPreview::ArticleViewPreview( const std::string& url )
     setup_view();
 
     // コントロールモード設定
-    get_control().set_mode( CONTROL::MODE_MESSAGE );
+    get_control().clear_mode();
+    get_control().add_mode( CONTROL::MODE_MESSAGE );
 }
 
 
@@ -62,7 +64,6 @@ void ArticleViewPreview::pack_widget()
 }
 
 
-
 //
 // viewの操作
 //
@@ -89,6 +90,10 @@ void ArticleViewPreview::operate_view( const int& control )
             MESSAGE::get_admin()->set_command( "tab_right" );
         break;
 
+        case CONTROL::FocusWrite:
+            MESSAGE::get_admin()->set_command( "focus_write" );
+        break;
+
         default:
             ArticleViewBase::operate_view( control );
             break;
@@ -107,3 +112,20 @@ void ArticleViewPreview::append_dat( const std::string& dat, int num )
     drawarea()->clear_screen();
     ArticleViewBase::append_dat( dat, get_article()->get_number_load() +1 );
 }
+
+
+//
+// drawarea のクリックイベント
+//
+// ArticleViewBase::slot_button_press()をオーパロードしてマウスジェスチャを無効にする
+//
+bool ArticleViewPreview::slot_button_press( std::string url, int res_number, GdkEventButton* event )
+{
+#ifdef _DEBUG
+    std::cout << "ArticleViewPreview::slot_button_press url = " << get_url() << std::endl;
+#endif
+
+    MESSAGE::get_admin()->set_command( "switch_admin" );
+
+    return true;
+}
