@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //#define _DEBUG
 #include "jddebug.h"
@@ -128,7 +128,7 @@ void Img::download_img()
 //
 // path_to はデフォルトのファイル名
 //
-bool Img::save( const std::string& path_to )
+bool Img::save( Gtk::Window* parent, const std::string& path_to )
 {
     if( is_loading() ) return false;
 
@@ -138,7 +138,7 @@ bool Img::save( const std::string& path_to )
     std::string name = MISC::get_filename( path_to );
     if( name.empty() ) name = MISC::get_filename( m_url );    
 
-    std::string save_to = CACHE::open_save_diag( CACHE::path_img( m_url ), dir + name );
+    std::string save_to = CACHE::open_save_diag( parent, CACHE::path_img( m_url ), dir + name );
 
     if( ! save_to.empty() ){
         SESSION::set_dir_img_save( MISC::get_dir( save_to ) );
@@ -266,7 +266,7 @@ void Img::receive_finish()
     // 読み込み失敗の場合はファイルを消しておく
     if( ! total_length() ){
         std::string path = CACHE::path_img( m_url );
-        if( CACHE::is_file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
+        if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
     }
 
     // 読み込み失敗の場合でもエラーメッセージを残すので info　は保存する
@@ -274,6 +274,7 @@ void Img::receive_finish()
 
     CORE::core_set_command( "redraw", m_url );
     CORE::core_set_command( "redraw_article" );
+    CORE::core_set_command( "redraw_message" );
 
 #ifdef _DEBUG
     std::cout << "Img::receive_finish code = " << get_code() << std::endl
